@@ -256,7 +256,7 @@ void setup_qt( TQImage& image, png_structp png_ptr, png_infop info_ptr )
 #endif
 		if (g < ncols) {
 		    image.setAlphaBuffer(TRUE);
-		    image.setColor(g, image.color(g) & TQRGB_MASK);
+		    image.setColor(g, image.color(g) & TQT_RGB_MASK);
 		}
 	    }
 	}
