@@ -221,10 +221,10 @@ static void read_xpm_image_or_array( TQImageIO * iio, const char * const * sourc
 	    int transparentColor = currentColor;
 	    if ( image.depth() == 8 ) {
 		image.setColor( transparentColor,
-				TQRGB_MASK & tqRgb(198,198,198) );
+				TQT_RGB_MASK & tqRgb(198,198,198) );
 		colorMap.insert( index, transparentColor );
 	    } else {
-		TQRgb rgb = TQRGB_MASK & tqRgb(198,198,198);
+		TQRgb rgb = TQT_RGB_MASK & tqRgb(198,198,198);
 		colorMap.insert( index, rgb );
 	    }
 	} else {
@@ -388,7 +388,7 @@ static void write_xpm_image( TQImageIO * iio )
     TQMap<TQRgb, int>::Iterator c = colorMap.begin();
     while ( c != colorMap.end() ) {
 	TQRgb color = c.key();
-	if ( image.hasAlphaBuffer() && color == (color & TQRGB_MASK) )
+	if ( image.hasAlphaBuffer() && color == (color & TQT_RGB_MASK) )
 	    line.sprintf( "\"%s c None\"",
 			  xpm_color_name(cpp, *c) );
 	else
